### Name: plot.Hist
### Title: Box-arrow diagrams for multi-state models
### Aliases: plot.Hist
### Keywords: survival

### ** Examples


## A simple survival model
## Not run: 
##D library(survival)
##D data(pbc)
##D SurvFrame <- pbc
##D ## or simply create some data
##D SurvFrame <- data.frame(time=1:10,status=sample(0:1,10,TRUE))
##D SurvHist <- with(SurvFrame,Hist(time,status))
##D plot(SurvHist,
##D      state.lab=c("Randomization","Death"),
##D      arrow.lab=expression(lambda(t)),
##D      layout=list(nrow=2,ncol=2,box.pos=list(c(1,1),c(2,2))))
##D 
##D ## two competing risks
##D comprisk.model <- data.frame(time=1:3,status=1:3)
##D CRHist <- with(comprisk.model,Hist(time,status,cens.code=2))
##D plot(CRHist,
##D      cex=2,
##D      state.lab=c("Alive","Dead\n cause 1","Dead\n cause 2"),
##D      style="character",ybox.rule=1,
##D      arrow.lab=c(expression(gamma[1](t),gamma[2](t))),
##D      enumerate.boxes=TRUE,
##D      cex.boxlabs = 1.28)
##D 
##D ## change the layout
##D plot(CRHist,
##D      cex=2,
##D      state.lab=c("Alive","Dead\n cause 1","Dead\n cause 2"),
##D      style="character",ybox.rule=1,
##D      arrow.lab=c(expression(gamma[1](t),gamma[2](t))),
##D      arrow.lab.side=c(1,-1),
##D      enumerate.boxes=TRUE,
##D      cex.boxlabs = 1.28,
##D      layout=list(nrow=2,ncol=3,box.pos=list(c(1,2),c(2,1),c(2,3))))
##D 
##D ## more competing risks
##D comprisk.model2 <- data.frame(time=1:4,status=1:4)
##D CRHist2 <- with(comprisk.model2,Hist(time,status,cens.code=2))
##D plot(CRHist2,
##D      cex=2,
##D      state.lab=c("Alive","Dead\n cause 1","Dead\n cause 2","Dead\n cause 3"),
##D      arrow.lab=c(expression(alpha[1](t),alpha[2](t),alpha[3](t))),
##D      enumerate.boxes=TRUE,
##D      ybox.rule=.8,
##D      verbose=FALSE,
##D      cex.boxlabs = 1.28)
##D 
##D ## change the layout
##D plot(CRHist2,
##D      cex=2,
##D      state.lab=c("Alive","Dead\n cause 1","Dead\n cause 2","Dead\n cause 3"),
##D      arrow.lab=c(expression(alpha[1](t),alpha[2](t),alpha[3](t))),
##D      enumerate.boxes=TRUE,
##D      ybox.rule=.8,
##D      verbose=FALSE,
##D      cex.boxlabs = 1.28,
##D      layout=list(nrow=3,ncol=3,box.pos=list(c(2,1),c(1,2),c(3,2),c(2,3))),
##D      reverse=FALSE,
##D      arrow.lab.side=c(-1,1,-1),
##D      arrow.lab.offset=c(7,9,8))
##D 
##D ## illness-death models
##D illness.death.frame <-
##D          data.frame(time=1:4,
##D                     from=c("Disease-free","Disease-free",
##D                       "Diseased","Disease-free"),
##D                     to=c("0","Diseased","Dead","Dead"))
##D IDHist <- with(illness.death.frame,
##D                Hist(time,event=list(from,to)))
##D plot(IDHist,
##D      ybox.rule=4,
##D      xbox.rule=.3,
##D      state.cex=1.3,
##D      enum=TRUE,
##D      arrow.lab.side=c(-1,-1,1))
##D 
##D ## illness-death with recovery
##D illness.death.frame2 <- data.frame(time=1:5,
##D                                    from=c("Disease\nfree","Disease\nfree",
##D                                      "Diseased","Diseased","Disease\nfree"),
##D                                    to=c("0","Diseased","Disease\nfree",
##D                                                            "Dead","Dead"))
##D IDHist2 <- with(illness.death.frame2,Hist(time,event=list(from,to)))
##D plot(IDHist2,
##D      ybox.rule=1.3,
##D      xbox.rule=.3,
##D      state.cex=2,
##D      arrow.lab.offset=c(13,13,8,10),
##D      enum=TRUE,
##D      verbose=FALSE)
##D ## change the layout
##D 
##D plot(IDHist2,
##D      ybox.rule=1.3,
##D      xbox.rule=.3,
##D      state.cex=2,
##D      enum=TRUE,
##D      verbose=FALSE,
##D      layout=list(ncol=3,nrow=2,box.pos=list(c(1,1),c(2,2),c(1,3))),
##D      arrow.lab.side=c(-1,1,-1,1),
##D      arrow.lab.offset=c(15,15,10,10))
##D  
## End(Not run)



