### Name: prodlim
### Title: product limit method
### Aliases: prodlim
### Keywords: survival nonparametric cluster

### ** Examples


##---------------------two-state survival model------------

dat <- SimSurv(100)
with(dat,plot(Hist(time,status)))
fit <- prodlim(Hist(time,status)~1,data=dat)
print(fit)
plot(fit)
summary(fit)

## --------------------clustered data---------------------

dat <- SimSurv(100,cova=list(patnr=list("rbinom",30,.5)),surv.baseline=1/10000000)
fit <- prodlim(Hist(time,status)~cluster(patnr),data=dat)
print(fit)
plot(fit)
summary(fit)

##-----------compare Kaplan-Meier to survival package---------

pfit <- prodlim(Surv(time,status)~1,data=pbc)
pfit <- prodlim(Hist(time,status)~1,data=pbc) ## same thing
sfit <- survfit(Surv(time,status)~1,data=pbc,conf.type="plain")
##  same result for the survival distribution function 
all(round(pfit$surv,12)==round(sfit$surv,12))
summary(pfit,digits=3)
summary(sfit,times=quantile(unique(pbc$time)))

##------------------censoring survival function----------------

rpfit <- prodlim(Hist(time,status)~1,data=pbc,reverse=TRUE)
rsfit <- survfit(Surv(time,1-status)~1,data=pbc,conf.type="plain") 
## not the same if there are ties!
all(round(rpfit$surv,3)==round(rsfit$surv,3))

##-------------------stratified Kaplan-Meier---------------------

pfit.edema <- prodlim(Surv(time,status)~edema,data=pbc)
summary(pfit.edema)
summary(pfit.edema,intervals=TRUE)
plot(pfit.edema)

##----------continuous covariate: Stone-Beran estimate------------

prodlim(Surv(time,status)~age,data=pbc)

##-------------both discrete and continuous covariates------------

prodlim(Surv(time,status)~edema+age,data=pbc)

##----------------------interval censored data----------------------

dat <- data.frame(L=1:10,R=c(2,3,12,8,9,10,7,12,12,12),status=c(1,1,0,1,1,1,1,0,0,0))
with(dat,Hist(time=list(L,R),event=status))

npmle.fitml <- prodlim(Hist(time=list(L,R),event=1)~1,data=dat,ml=TRUE)

##-------------competing risks-------------------

CompRiskFrame <- data.frame(time=1:100,event=rbinom(100,2,.5),X=rbinom(100,1,.5))
crFit <- prodlim(Hist(time,event)~X,data=CompRiskFrame)
summary(crFit)
plot(crFit)
summary(crFit,cause=2)
plot(crFit,cause=2)




